@@ -19,7 +19,7 @@ class IssueForm(forms.Form):
             connection = Connection(settings.YOUTRACK_URL, settings.YOUTRACK_LOGIN, settings.YOUTRACK_PASSWORD)
             response, content = connection.createIssue(self.project, assignee=None,
                                                        summary=u'Issue from feedback form',
-                                                       description=self.cleaned_data['description'])
+                                                       description=self.cleaned_data['description'].encode('utf-8'))
             issue_id = response['location'].split('/')[-1]
             commands = ''
             if self.subsystem is not None:
